# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nexus`](#nexus): Install and configure Sonatype Nexus Repository Manager 3.
* [`nexus::plugin::composer`](#nexusplugincomposer): Install the composer repository format plugin

#### Private Classes

* `nexus::config`: Configure nexus repository manager
* `nexus::package`: Install the Nexus Repository Manager package
* `nexus::plugin`: Base class used by plugin classes
* `nexus::service`: Maintains the Nexus service
* `nexus::user`: Manages the operation system user account which is used to start up the service

## Classes

### <a name="nexus"></a>`nexus`

Install and configure Sonatype Nexus Repository Manager 3.

* **See also**
  * https://help.sonatype.com/repomanager3/product-information/download/download-archives---repository-manager-3

#### Examples

##### 

```puppet
class{ 'nexus':
  version => '3.37.3-02',
}
```

#### Parameters

The following parameters are available in the `nexus` class:

* [`version`](#version)
* [`download_folder`](#download_folder)
* [`download_site`](#download_site)
* [`download_proxy`](#download_proxy)
* [`install_root`](#install_root)
* [`work_dir`](#work_dir)
* [`user`](#user)
* [`group`](#group)
* [`host`](#host)
* [`port`](#port)
* [`manage_user`](#manage_user)
* [`manage_config`](#manage_config)
* [`manage_work_dir`](#manage_work_dir)
* [`purge_installations`](#purge_installations)

##### <a name="version"></a>`version`

Data type: `Pattern[/3.\d+.\d+-\d+/]`

The version to download, install and manage.

##### <a name="download_folder"></a>`download_folder`

Data type: `Stdlib::Absolutepath`

Destination folder of the downloaded archive.

##### <a name="download_site"></a>`download_site`

Data type: `Stdlib::HTTPUrl`

Download uri which will be appended with filename of the archive to download.

##### <a name="download_proxy"></a>`download_proxy`

Data type: `Optional[Stdlib::HTTPUrl]`

Proxyserver address which will be used to download the archive file.

##### <a name="install_root"></a>`install_root`

Data type: `Stdlib::Absolutepath`

The root filesystem path where the downloaded archive will be extracted to.

##### <a name="work_dir"></a>`work_dir`

Data type: `Stdlib::Absolutepath`

The nexus repository manager working directory which contains the embedded database and local blobstores.

##### <a name="user"></a>`user`

Data type: `String[1]`

The operation system user used to start the nexus repository manager service.

##### <a name="group"></a>`group`

Data type: `String[1]`

The operation system group used to start the nexus repository manager service.

##### <a name="host"></a>`host`

Data type: `Stdlib::Host`

The bind address where the nexus repository manager service should bind to.

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

The port which the nexus repository manager service should use.

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Set if this module should manage the creation of the operation system user.

##### <a name="manage_config"></a>`manage_config`

Data type: `Boolean`

Set if this module should manage the config file of nexus repository manager.

##### <a name="manage_work_dir"></a>`manage_work_dir`

Data type: `Boolean`

Set if this module should manage the work directory of the nexus repository manager.

##### <a name="purge_installations"></a>`purge_installations`

Data type: `Boolean`

Set this option if you want old installations of nexus repository manager to get automatically deleted.

### <a name="nexusplugincomposer"></a>`nexus::plugin::composer`

Install the composer repository format plugin

#### Examples

##### 

```puppet
class { 'nexus':
   version => '3.34.3-02',
}
class { 'nexus::plugin::composer':
   version => '0.0.18',
}
```

#### Parameters

The following parameters are available in the `nexus::plugin::composer` class:

* [`version`](#version)

##### <a name="version"></a>`version`

Data type: `Pattern[/\d+.\d+.\d+/]`

The composer repository format plugin version.

